@@ -266,14 +266,15 @@ class ModelBaseAdmin(admin.ModelAdmin):
     def _actions(self, obj):
         # Deliberately add simple inline javascript here to avoid having to
         # customize change_list.html.
+        args = [obj._meta.app_label, obj.__class__.__name__]
         result = ''
         if obj.state == 'unpublished':
-            url = "%s?id=%s" % (reverse('molo-publish-ajax'), obj.id)
+            url = "%s?id=%s" % (reverse('molo-publish-ajax', args=args), obj.id)
             result += '''<a href="%s" \
 onclick="django.jQuery.get('%s'); django.jQuery(this).replaceWith('Published'); return false;">
 Publish</a><br />''' % (url, url)
         if obj.state == 'published':
-            url = "%s?id=%s" % (reverse('molo-unpublish-ajax'), obj.id)
+            url = "%s?id=%s" % (reverse('molo-unpublish-ajax', args=args), obj.id)
             result += '''<a href="%s" \
 onclick="django.jQuery.get('%s'); django.jQuery(this).replaceWith('Unpublished'); return false;">
 Unpublish</a><br />''' % (url, url)
